@@ -24,8 +24,8 @@ class MultiProcess:
         """Creates a new multiproceess object
 
         Args:
-            tasks (List[Task], optional): Tasks to innit with. More can be added later. Defaults to [].
-        """    
+            tasks (List[Optional[Task]], optional): Tasks to innit with. More can be added later. Defaults to [].
+        """
         self.tasks = tasks
 
 
